@@ -1,6 +1,6 @@
 package Bundle::WWW::Search::ALL;
 
-$VERSION = '1.17';
+$VERSION = '1.18';
 
 __END__
 
@@ -18,6 +18,8 @@ C<perl -MCPAN -e 'install Bundle::WWW::Search::ALL'>
 
 Bundle::WWW::Search
 
+WWW::Search::AltaVista
+
 WWW::Search::AlltheWeb
 
 J/JS/JSMYSER/WWW-Search-AltaVista-AdvancedWeb-2.02.tar.gz
@@ -26,31 +28,21 @@ WWW::Search::Ebay
 
 J/JS/JSMYSER/WWW-Search-EuroSeek-1.03.tar.gz
 
-WWW::Search::Excite
-
-J/JS/JSMYSER/WWW-Search-Excite-News-2.04.tar.gz
-
 WWW::Search::FirstGov
 
 WWW::Search::Go
 
 J/JS/JSMYSER/WWW-Search-GoTo-1.07.tar.gz
 
-J/JS/JSMYSER/WWW-Search-Google-2.21.tar.gz
-
 WWW::Search::HotBot
 
 WWW::Search::Jobs
 
 J/JS/JSMYSER/WWW-Search-LookSmart-2.05.tar.gz
 
-WWW::Search::Lycos
-
-WWW::Search::Magellan
-
 J/JS/JSMYSER/WWW-Search-MetaCrawler-2.07.tar.gz
 
-J/JS/JSMYSER/WWW-Search-News-2.05.tar.gz
+WWW::Search::News
 
 WWW::Search::Nomade
 
@@ -62,6 +54,8 @@ WWW::Search::PRWire
 
 WWW::Search::PubMed
 
+WWW::Search::RpmFind
+
 J/JS/JSMYSER/WWW-Search-Snap-2.06.tar.gz
 
 WWW::Search::Translator
@@ -74,6 +68,7 @@ WWW::Search::YahooNews
 
 J/JS/JSMYSER/WWW-Search-ZDNet-2.02+.tar.gz
 
+
 =head1 DESCRIPTION
 
 This bundle gathers together all of the modules for WWW::Search,
@@ -84,7 +79,7 @@ author:
 
 =head1 AUTHOR
 
-Martin Thurn E<lt>F<martinthurn@iname.com>E<gt>
+Martin Thurn E<lt>F<mthurn@cpan.org>E<gt>
 (Author only of this bundle, not necessarily of the modules it lists)
 
 =cut
